# CHANGELOG


## v0.4.2 (2026-03-19)

### Bug Fixes

- Trigger release
  ([`cd8a555`](https://github.com/lou-k/kissml/commit/cd8a55519163267a77022caed952ff2e35d14417))


## v0.4.1 (2026-01-27)

### Bug Fixes

- Speed up cache key gen time for dataframes
  ([`61eb28b`](https://github.com/lou-k/kissml/commit/61eb28bbd5c83c742e0f35169976dc89182e0c01))


## v0.4.0 (2026-01-19)

### Features

- Add namespace option
  ([`854a46e`](https://github.com/lou-k/kissml/commit/854a46ef22c6ca3aad73fa5d272c4d28b5c6f669))


## v0.3.0 (2026-01-19)

### Features

- Write multi-dim numpy arrays as bytes when serializing
  ([`cbba610`](https://github.com/lou-k/kissml/commit/cbba61054dae359f5b2fe00ac03a06eec7be8b1a))


## v0.2.0 (2026-01-09)

### Features

- Add numpy array to unhashable types
  ([`0ae81f9`](https://github.com/lou-k/kissml/commit/0ae81f975c8d9e3c6f27292c124059ad94866381))


## v0.1.2 (2026-01-09)

### Bug Fixes

- Stringfiy unhashable types in pandas containers
  ([`08fc7e6`](https://github.com/lou-k/kissml/commit/08fc7e6c82955282a83c9dad484431193aee9d6b))


## v0.1.1 (2026-01-09)

### Bug Fixes

- Switch to shah256 for default hash function
  ([`6bbb754`](https://github.com/lou-k/kissml/commit/6bbb754e620f0db4d356a460b7a73621015aec95))

- Switch to shah256 for default hash function
  ([`981718d`](https://github.com/lou-k/kissml/commit/981718d2c3c1d4429564b3b92d9954199b8e39dc))


## v0.1.0 (2026-01-07)

### Features

- Support after effects for step return types ([#2](https://github.com/lou-k/kissml/pull/2),
  [`d5ef88c`](https://github.com/lou-k/kissml/commit/d5ef88c968271c4148db7b355af7cef2b1490276))

* feat: Support after effects for step return types

* fix exports

* Update README.md

Co-authored-by: Copilot <175728472+Copilot@users.noreply.github.com>

* Update kissml/step.py

Co-authored-by: Copilot <175728472+Copilot@users.noreply.github.com>

* fix typing issues, typos

* avoid settings conflicts

---------

Co-authored-by: Lou <lou@lou.dev> Co-authored-by: Copilot
  <175728472+Copilot@users.noreply.github.com>


## v0.0.1 (2026-01-04)

### Bug Fixes

- Restore PyPI deployment configuration
  ([`d510f70`](https://github.com/lou-k/kissml/commit/d510f703b205b43246d3701126a2e575e81b0df7))

- Restore PyPI environment in workflow - Simplify CI/CD configuration

### Documentation

- Update Contributing Guide for Conventional Commits
  ([`69f0e8d`](https://github.com/lou-k/kissml/commit/69f0e8dba492d289ca0f7fc71969c82a23cfa08f))


## v0.0.0 (2026-01-02)
